@@ -20,7 +20,7 @@ class RecurrenceWidget(forms.Textarea):
     def get_media(self):
         extra = '' if settings.DEBUG else '.min'
         js = [
-            'vendor/jquery/jquery%s.js' % extra,
+            'admin/js/vendor/jquery/jquery%s.js' % extra,
             'admin/js/jquery.init.js',
             staticfiles_storage.url('recurrence/js/recurrence.js'),
             staticfiles_storage.url('recurrence/js/recurrence-widget.js'),
